@@ -1,4 +1,6 @@
 context("Predictions and OOB Predictions")
+## temporary fix for R-dev
+suppressWarnings(RNGversion("3.5.0"))
 library(rerf)
 
 set.seed(123456)
@@ -16,7 +18,7 @@ Y.test <- Y[-trainIdx]
 
 test_that("OOB predictions fails when OOB indices not stored", {
   forest <- RerF(X, Y, seed = 1L, num.cores = 1L, store.oob = FALSE)
-  oob.predictions <- expect_error(OOBPredict(X, forest))
+  expect_error(OOBPredict(X, forest))
 })
 
 test_that("Predictions fail when training data not given for rank.transform", {
@@ -24,7 +26,7 @@ test_that("Predictions fail when training data not given for rank.transform", {
     seed = 1L, num.cores = 1L, store.oob = TRUE,
     min.parent = 1, max.depth = 0, rank.transform = TRUE
   )
-  expect_error(oob.predictions <- OOBPredict(X, forest))
+  expect_error(OOBPredict(X, forest))
 })
 
 test_that("Test fails when input is not matrix", {
@@ -44,7 +46,7 @@ test_that("Iris OOB Predictions", {
   )
   oob.predictions <- OOBPredict(X, forest, num.cores = 1L)
   accuracy <- mean(Y == oob.predictions)
-  expect_equal(accuracy, 143 / 150)
+  expect_true(accuracy >= 140 / 150)
 
   # Limit depth of trees
   forest <- RerF(X, Y,
@@ -53,7 +55,7 @@ test_that("Iris OOB Predictions", {
   )
   oob.predictions <- OOBPredict(X, forest, num.cores = 2L)
   accuracy <- mean(Y == oob.predictions)
-  expect_equal(accuracy, 133 / 150)
+  expect_true(accuracy >= 130 / 150)
 })
 
 test_that("Iris Predictions", {
@@ -64,7 +66,7 @@ test_that("Iris Predictions", {
   )
   predictions <- Predict(X.test, forest, num.cores = 1L)
   accuracy <- mean(Y.test == predictions)
-  expect_equal(accuracy, 64 / 70)
+  expect_true(accuracy >= 60 / 70)
 
   # Limit depth of trees
   forest <- RerF(X.train, Y.train,
@@ -73,7 +75,7 @@ test_that("Iris Predictions", {
   )
   predictions <- Predict(X.test, forest, num.cores = 1L)
   accuracy <- mean(Y.test == predictions)
-  expect_equal(accuracy, 63 / 70)
+  expect_true(accuracy >= 60 / 70)
 })
 
 test_that("Output probabilities should equal 1", {
@@ -106,3 +108,10 @@ test_that("Not aggregate output, probabilities should still equal 1", {
     expect_equal(rep(1, nrows), rowSums(tree.predictions))
   }
 })
+
+
+
+## reset RNG to current version
+si <- sessionInfo()
+vstr <- paste0(si$R.version$major,".", si$R.version$minor)
+RNGversion(vstr)
